# Audio Testing Guide for DryBox

## Setup Verification

1. **Start the server first**:
   ```bash
   python server.py
   ```

2. **Run the UI**:
   ```bash
   python UI/main.py
   ```

## Testing Audio Playback

### Step 1: Test PyAudio is Working
When you enable playback (Ctrl+1 or Ctrl+2), you should hear a short beep (100ms, 1kHz tone). This confirms:
- PyAudio is properly installed
- Audio output device is working
- Stream format is correct

### Step 2: Test During Call
1. Click "Run Automatic Test" or press Space
2. **Immediately** enable playback on Phone 2 (Ctrl+2)
   - You should hear the test beep
3. Watch the debug console for:
   - "Phone 2 playback started"
   - "Phone 2 sent test beep to verify audio"
4. Wait for handshake to complete (steps 4-5 in test)
5. Once voice session starts, you should see:
   - "Phone 2 received audio data: XXX bytes"
   - "Phone 2 forwarding audio to player"
   - "Client 1 playback thread got XXX bytes"

### What to Look For in Debug Console

**Good signs:**
```
[AudioPlayer] Client 1 add_audio_data called with 640 bytes
[AudioPlayer] Client 1 added to buffer, queue size: 1
[AudioPlayer] Client 1 playback thread got 640 bytes
```

**Problem signs:**
```
[AudioPlayer] Client 1 has no buffer (playback not started?)
Low confidence demodulation: 0.XX
Codec decode returned None or empty
```

## Troubleshooting

### No Test Beep
- Check system volume
- Verify PyAudio: `python test_audio_setup.py`
- Check audio device: `python -c "import pyaudio; p=pyaudio.PyAudio(); print(p.get_default_output_device_info())"`

### Test Beep Works but No Voice Audio
1. **Check if audio is being transmitted:**
   - Phone 1 should show: "sent N voice frames"
   - Phone 2 should show: "Received voice data frame #N"

2. **Check if audio is being decoded:**
   - Look for: "Decoded PCM samples: type=<class 'numpy.ndarray'>, len=320"
   - Look for: "Emitting PCM bytes: 640 bytes"

3. **Check if audio reaches the player:**
   - Look for: "Phone 2 received audio data: 640 bytes"
   - Look for: "Client 1 add_audio_data called with 640 bytes"

### Audio Sounds Distorted
This is normal! The system uses:
- Codec2 at 1200bps (very low bitrate)
- 4FSK modulation
- This creates robotic/vocoder-like sound

### Manual Testing Commands

Test just the codec:
```python
python test_audio_pipeline.py
```

Play the test outputs:
```bash
# Original
aplay wav/input.wav

# Codec only (should sound robotic)
aplay wav/test_codec_only.wav

# Full pipeline (codec + FSK)
aplay wav/test_full_pipeline.wav
```

## Expected Audio Flow

1. Phone 1 reads `wav/input.wav` (8kHz mono)
2. Encodes 320 samples (40ms) with Codec2 → 6 bytes
3. Modulates with 4FSK → ~1112 float samples
4. Encrypts with Noise XK
5. Sends to server
6. Server routes to Phone 2
7. Phone 2 decrypts with Noise XK
8. Demodulates FSK → 6 bytes
9. Decodes with Codec2 → 320 samples (640 bytes PCM)
10. Sends to PyAudio for playback

## Recording Feature

To save received audio:
1. Press Alt+1 or Alt+2 to start recording
2. Let it run during the call
3. Press again to stop and save
4. Check `wav/` directory for saved files

This helps verify if audio is being received even if playback isn't working.