# Phone 2 Playback - What It Actually Plays

## The Complete Audio Flow for Phone 2

When Phone 2 receives audio, it goes through this exact process:

### 1. Network Reception
- Encrypted data arrives from server
- Data includes Noise XK encrypted voice frames

### 2. Decryption (Noise XK)
- `protocol_phone_client.py` line 156-165: Noise wrapper decrypts the data
- Result: Decrypted voice message containing FSK modulated signal

### 3. Demodulation (4FSK)
- `_handle_voice_data()` line 223: FSK demodulation
- Converts modulated signal back to 6 bytes of compressed data
- Only processes if confidence > 0.5

### 4. Decompression (Codec2 Decode)
- Line 236: `pcm_samples = self.codec.decode(frame)`
- Converts 6 bytes → 320 samples (640 bytes PCM)
- This is the final audio ready for playback

### 5. Playback
- Line 264: `self.data_received.emit(pcm_bytes, self.client_id)`
- PCM audio sent to audio player
- PyAudio plays the 16-bit, 8kHz mono audio

## What You Hear on Phone 2

Phone 2 plays audio that has been:
- ✅ Encrypted → Decrypted (Noise XK)
- ✅ Modulated → Demodulated (4FSK)  
- ✅ Compressed → Decompressed (Codec2)

The audio will sound:
- **Robotic/Vocoder-like** due to 1200bps Codec2 compression
- **Slightly delayed** due to processing pipeline
- **But intelligible** - you can understand speech

## Fixed Issues

1. **Silent beginning**: Now skips first second of silence in input.wav
2. **Control messages**: No longer sent to audio player
3. **Debug spam**: Reduced to show only important frames

## Testing Phone 2 Playback

1. Run automatic test (Space)
2. Enable Phone 2 playback (Ctrl+2)
3. Wait for handshake to complete
4. You should hear:
   - Audio starting from 1 second into input.wav
   - Processed through full protocol stack
   - Robotic but understandable audio

The key point: Phone 2 IS playing fully processed audio (decrypted + demodulated + decompressed)!