# Fixed Audio Playback Guide

## How Playback Now Works

### Phone 1 (Sender) Playback
- **What it plays**: Original audio from `input.wav` BEFORE encoding
- **When to enable**: During a call to hear what you're sending
- **Audio quality**: Clear, unprocessed 8kHz mono audio

### Phone 2 (Receiver) Playback  
- **What it plays**: Decoded audio AFTER the full pipeline (Codec2 → FSK → Noise XK → transmission → decryption → demodulation → decoding)
- **When to enable**: During a call to hear what's being received
- **Audio quality**: Robotic/vocoder sound due to 1200bps Codec2 compression

## Changes Made

1. **Fixed control message routing** - 8-byte control messages no longer sent to audio player
2. **Phone 1 now plays original audio** when sending (before encoding)
3. **Removed test beep** - you'll hear actual audio immediately
4. **Added size filter** - only audio data (≥320 bytes) is processed

## Testing Steps

1. Start server: `python server.py`
2. Start UI: `python UI/main.py`
3. Run automatic test (Space key)
4. **For Phone 1 playback**: Press Ctrl+1 to hear the original `input.wav` being sent
5. **For Phone 2 playback**: Press Ctrl+2 to hear the decoded audio after transmission

## Expected Debug Output

**Good signs for Phone 1 (sender):**
```
Phone 1 playing original audio (sender playback)
[AudioPlayer] Client 0 add_audio_data called with 640 bytes
```

**Good signs for Phone 2 (receiver):**
```
Phone 2 received audio data: 640 bytes
Phone 2 forwarding audio to player (playback enabled)
[AudioPlayer] Client 1 add_audio_data called with 640 bytes
```

**Fixed issues:**
```
Phone 2 received non-audio data: 8 bytes (ignoring)  # Control messages now filtered out
```

## Audio Quality Expectations

- **Phone 1**: Should sound identical to `input.wav`
- **Phone 2**: Will sound robotic/compressed due to:
  - Codec2 compression at 1200bps (very low bitrate)
  - 4FSK modulation/demodulation
  - This is normal and proves the protocol is working!

## Troubleshooting

If you still don't hear audio:

1. **Check debug console** for the messages above
2. **Verify handshake completes** before expecting audio
3. **Try recording** (Alt+1/2) to save audio for offline playback
4. **Check system volume** and audio device

The most important fix: control messages are no longer sent to the audio player, so you should only receive actual 640-byte audio frames.