# Audio Playback Implementation Summary

## Key Fixes Applied

### 1. Separated Sender vs Receiver Playback
- **Phone 1 (Sender)**: Now plays the original `input.wav` audio when transmitting
- **Phone 2 (Receiver)**: Plays the decoded audio after full protocol processing

### 2. Fixed Control Message Routing
- Control messages (like "CALL_END" - 8 bytes) no longer sent to audio player
- Added size filter: only data ≥320 bytes is considered audio
- Removed problematic `data_received.emit()` for non-audio messages

### 3. Improved Debug Logging
- Reduced verbosity: logs only first frame and every 25th frame
- Clear indication of what's happening at each stage
- Separate logging for sender vs receiver playback

### 4. Code Changes Made

**phone_manager.py**:
- Added original audio playback for sender
- Added size filter for received data
- Improved debug logging with frame counters

**protocol_phone_client.py**:
- Removed control message emission to data_received
- Added confidence logging for demodulation
- Reduced debug verbosity

**audio_player.py**:
- Added frame counting for debug
- Reduced playback thread logging
- Better buffer status reporting

**main.py**:
- Fixed lambda signal connection issue
- Improved UI scaling with flexible layouts

## How to Test

1. Start server and UI
2. Run automatic test (Space)
3. Enable playback:
   - **Ctrl+1**: Hear original audio from Phone 1
   - **Ctrl+2**: Hear decoded audio on Phone 2

## Expected Behavior

**Phone 1 with playback enabled:**
- Clear audio matching `input.wav`
- Shows "playing original audio (sender playback)"

**Phone 2 with playback enabled:**
- Robotic/compressed audio (normal for 1200bps)
- Shows "received audio frame #N: 640 bytes"
- No more "8 bytes" messages

## Audio Flow
```
Phone 1:                          Phone 2:
input.wav (8kHz)                  
   ↓                              
[Playback here if enabled]        
   ↓                              
Codec2 encode (1200bps)           
   ↓                              
4FSK modulate                     
   ↓                              
Noise XK encrypt                  
   ↓                              
→ Network transmission →          
                                  ↓
                                  Noise XK decrypt
                                  ↓
                                  4FSK demodulate
                                  ↓
                                  Codec2 decode
                                  ↓
                                  [Playback here if enabled]
```

The playback now correctly plays audio at the right points in the pipeline!