# DryBox - Secure Voice Over GSM Protocol

A secure voice communication protocol that transmits encrypted voice data over standard GSM voice channels.

## Architecture

- **Noise XK Protocol**: Provides authenticated key exchange and secure channel
- **Codec2**: Voice compression (1200 bps mode)
- **4FSK Modulation**: Converts digital data to audio tones
- **Encryption**: ChaCha20-Poly1305 for secure communication

## Project Structure

```
DryBox/
├── UI/                    # User interface components
│   ├── main.py           # Main PyQt5 application
│   ├── phone_manager.py  # Phone state management
│   ├── protocol_phone_client.py  # Protocol client implementation
│   ├── noise_wrapper.py  # Noise XK wrapper
│   └── ...
├── simulator/            # GSM channel simulator
│   └── gsm_simulator.py  # Simulates GSM voice channel
├── voice_codec.py        # Codec2 and FSK modem implementation
├── encryption.py         # Encryption utilities
└── wav/                  # Audio test files

```

## Running the Protocol

1. Start the GSM simulator:
```bash
cd simulator
python3 gsm_simulator.py
```

2. Run the UI application:
```bash
./run_ui.sh
# or
python3 UI/main.py
```

## Usage

1. Click "Call" on Phone 1 to initiate
2. Click "Answer" on Phone 2 to accept
3. The protocol will automatically:
   - Establish secure connection via Noise XK
   - Start voice session
   - Compress and encrypt voice data
   - Transmit over simulated GSM channel

## Requirements

- Python 3.6+
- PyQt5
- dissononce (Noise protocol)
- numpy (optional, for optimized audio processing)