# DryBox UI Features Guide

## UI Improvements
The UI has been updated with responsive layouts that scale better:
- Phone displays now use flexible sizing (min/max constraints)
- Waveform widgets adapt to available space
- Buttons have flexible widths that scale with window size
- Better margins and padding for improved visual appearance

## Audio Playback Feature

The DryBox UI includes real-time audio playback capabilities that allow you to hear the decoded audio as it's received.

### How to Use Playback

#### Manual Control
1. **During a Call**: Once a secure voice session is established, click the "🔊 Playback" button under either phone
2. **Button States**:
   - Gray (unchecked): Playback disabled
   - Green (checked): Playback active
3. **Toggle Anytime**: You can enable/disable playback at any time during a call

#### Keyboard Shortcuts
- `Ctrl+1`: Toggle playback for Phone 1
- `Ctrl+2`: Toggle playback for Phone 2

### Using Playback with Automatic Test

The automatic test feature demonstrates the complete protocol flow. Here's how to use it with playback:

1. **Start the Test**: Click "🧪 Run Automatic Test" or press `Space`
2. **Enable Playback Early**: 
   - As soon as the test starts, enable playback on Phone 2 (Ctrl+2)
   - This ensures you'll hear audio as soon as the secure channel is established
3. **What You'll Hear**:
   - Once handshake completes (step 4-5), Phone 1 starts transmitting test audio
   - Phone 2 will play the received, decoded audio through your speakers
   - The audio goes through: Codec2 encoding → 4FSK modulation → Noise XK encryption → transmission → decryption → demodulation → Codec2 decoding

### Audio Recording Feature

You can also record received audio for later analysis:

1. **Start Recording**: Click "⏺ Record" button (or press Alt+1/Alt+2)
2. **Stop Recording**: Click the button again
3. **Files Saved**: Recordings are saved to `wav/` directory with timestamps

### Audio Processing Options

Access advanced audio features via "Audio Options" button (Ctrl+A):
- **Export Buffer**: Save current audio buffer to file
- **Clear Buffer**: Clear accumulated audio data
- **Processing Options**:
  - Normalize Audio
  - Apply Gain (adjustable dB)
  - Noise Gate
  - Low/High Pass Filters
  - Remove Silence

### Requirements

For playback to work, you need PyAudio installed:
```bash
# Fedora/RHEL
sudo dnf install python3-devel portaudio-devel
pip install pyaudio

# Ubuntu/Debian
sudo apt-get install python3-dev portaudio19-dev
pip install pyaudio
```

If PyAudio isn't installed, recording will still work but playback will be disabled.

### Troubleshooting

1. **No Sound**: 
   - Check PyAudio is installed
   - Ensure system volume is up
   - Verify audio device is working
   
2. **Choppy Audio**:
   - Normal for low-bitrate codec (1200bps)
   - Represents actual protocol performance

3. **Delayed Start**:
   - Audio only flows after secure handshake
   - Wait for "🔒 Secure Channel Established" status

### Test Sequence Overview

The automatic test goes through these steps:
1. Initial state check
2. Phone 1 calls Phone 2
3. Phone 2 answers
4. Noise XK handshake begins
5. Handshake completes, secure channel established
6. Voice session starts (Codec2 + 4FSK)
7. Audio transmission begins
8. Protocol details logged
9. Transmission continues for observation
10. Final statistics
11. Call ends, cleanup

Enable playback on the receiving phone to hear the transmitted audio in real-time!