#!/usr/bin/env python3
"""
Test to verify audio is flowing through the system
"""

import os
import wave
import struct

def check_audio_file():
    """Verify input.wav has actual audio content"""
    print("Checking input.wav content...")
    
    with wave.open("wav/input.wav", 'rb') as wf:
        # Read multiple frames to check for silence
        total_frames = wf.getnframes()
        print(f"Total frames: {total_frames}")
        
        # Check beginning
        wf.setpos(0)
        frames = wf.readframes(320)
        samples = struct.unpack('320h', frames)
        max_val = max(abs(s) for s in samples)
        print(f"Frame 0 (beginning): max amplitude = {max_val}")
        
        # Check middle
        wf.setpos(total_frames // 2)
        frames = wf.readframes(320)
        samples = struct.unpack('320h', frames)
        max_val = max(abs(s) for s in samples)
        print(f"Frame {total_frames//2} (middle): max amplitude = {max_val}")
        
        # Check near end
        wf.setpos(total_frames - 640)
        frames = wf.readframes(320)
        samples = struct.unpack('320h', frames)
        max_val = max(abs(s) for s in samples)
        print(f"Frame {total_frames-640} (near end): max amplitude = {max_val}")
        
        # Find first non-silent frame
        wf.setpos(0)
        for i in range(0, total_frames, 320):
            frames = wf.readframes(320)
            if len(frames) < 640:
                break
            samples = struct.unpack('320h', frames)
            max_val = max(abs(s) for s in samples)
            if max_val > 100:  # Not silence
                print(f"\nFirst non-silent frame at position {i}")
                print(f"First 10 samples: {samples[:10]}")
                break

def main():
    # Change to DryBox directory if needed
    if os.path.basename(os.getcwd()) != 'DryBox':
        if os.path.exists('DryBox'):
            os.chdir('DryBox')
    
    check_audio_file()
    
    print("\nTo fix silence at beginning of file:")
    print("1. Skip initial silence in phone_manager.py")
    print("2. Or use a different test file")
    print("3. Or trim the silence from input.wav")

if __name__ == "__main__":
    main()